@@ -26,23 +26,20 @@
  ******************************************************************************/
 #pragma once
 
-
 #ifdef THRUST_DEBUG_SYNC
-#define THRUST_DEBUG_SYNC_FLAG true
-#define CUB_DEBUG_SYNC
+#  define THRUST_DEBUG_SYNC_FLAG true
+#  define CUB_DEBUG_SYNC
 #else
-#define THRUST_DEBUG_SYNC_FLAG false
+#  define THRUST_DEBUG_SYNC_FLAG false
 #endif
 
-
 #include <thrust/detail/config.h>
 
 // We don't directly include <cub/version.cuh> since it doesn't exist in
 // older releases. This header will always pull in version info:
-#include <cub/util_namespace.cuh>
-#include <cub/util_debug.cuh>
-
 #include <cub/detail/detect_cuda_runtime.cuh>
+#include <cub/util_debug.cuh>
+#include <cub/util_namespace.cuh>
 
 /**
  * \def THRUST_RUNTIME_FUNCTION
@@ -58,7 +55,7 @@
  * Defined if RDC is enabled.
  */
 #ifdef CUB_RDC_ENABLED
-#define THRUST_RDC_ENABLED
+#  define THRUST_RDC_ENABLED
 #endif
 
 /**
@@ -74,9 +71,9 @@
  * Replace any usages with `THRUST_RDC_ENABLED` and `NV_IF_TARGET`.
  */
 #ifdef CUB_RUNTIME_ENABLED
-#define __THRUST_HAS_CUDART__ 1
+#  define __THRUST_HAS_CUDART__ 1
 #else
-#define __THRUST_HAS_CUDART__ 0
+#  define __THRUST_HAS_CUDART__ 0
 #endif
 
 // These definitions were intended for internal use only and are now obsolete.
@@ -87,35 +84,35 @@
 // them available again. These should be considered deprecated and will be
 // fully removed in a future version.
 #ifdef THRUST_PROVIDE_LEGACY_ARCH_MACROS
-#ifdef __CUDA_ARCH__
-#define THRUST_DEVICE_CODE
-#endif // __CUDA_ARCH__
+#  ifdef __CUDA_ARCH__
+#    define THRUST_DEVICE_CODE
+#  endif // __CUDA_ARCH__
 #endif // THRUST_PROVIDE_LEGACY_ARCH_MACROS
 
 #ifdef THRUST_AGENT_ENTRY_NOINLINE
-#define THRUST_AGENT_ENTRY_INLINE_ATTR __noinline__
+#  define THRUST_AGENT_ENTRY_INLINE_ATTR __noinline__
 #else
-#define THRUST_AGENT_ENTRY_INLINE_ATTR _CCCL_FORCEINLINE
+#  define THRUST_AGENT_ENTRY_INLINE_ATTR _CCCL_FORCEINLINE
 #endif
 
 #define THRUST_DEVICE_FUNCTION _CCCL_DEVICE _CCCL_FORCEINLINE
-#define THRUST_HOST_FUNCTION _CCCL_HOST     _CCCL_FORCEINLINE
-#define THRUST_FUNCTION _CCCL_HOST_DEVICE _CCCL_FORCEINLINE
+#define THRUST_HOST_FUNCTION   _CCCL_HOST _CCCL_FORCEINLINE
+#define THRUST_FUNCTION        _CCCL_HOST_DEVICE _CCCL_FORCEINLINE
 
 #if 0
-#define THRUST_ARGS(...) __VA_ARGS__
-#define THRUST_STRIP_PARENS(X) X
-#define THRUST_AGENT_ENTRY(ARGS) THRUST_FUNCTION static void entry(THRUST_STRIP_PARENS(THRUST_ARGS ARGS))
+#  define THRUST_ARGS(...)         __VA_ARGS__
+#  define THRUST_STRIP_PARENS(X)   X
+#  define THRUST_AGENT_ENTRY(ARGS) THRUST_FUNCTION static void entry(THRUST_STRIP_PARENS(THRUST_ARGS ARGS))
 #else
-#define THRUST_AGENT_ENTRY(...) THRUST_AGENT_ENTRY_INLINE_ATTR _CCCL_DEVICE static void entry(__VA_ARGS__)
+#  define THRUST_AGENT_ENTRY(...) THRUST_AGENT_ENTRY_INLINE_ATTR _CCCL_DEVICE static void entry(__VA_ARGS__)
 #endif
 
 #ifndef THRUST_IGNORE_CUB_VERSION_CHECK
 
-#include <thrust/version.h>
-#if THRUST_VERSION != CUB_VERSION
+#  include <thrust/version.h>
+#  if THRUST_VERSION != CUB_VERSION
 #error The version of CUB in your include path is not compatible with this release of Thrust. CUB is now included in the CUDA Toolkit, so you no longer need to use your own checkout of CUB. Define THRUST_IGNORE_CUB_VERSION_CHECK to ignore this.
-#endif
+#  endif
 
 // Make sure the CUB namespace has been declared using the modern macros:
 CUB_NAMESPACE_BEGIN // cppcheck-suppress unknownMacro
@@ -126,14 +123,16 @@ CUB_NAMESPACE_END
 // Make sure the CUB namespace has been declared. Use the old macros for compat
 // with older CUB:
 CUB_NS_PREFIX
-namespace cub {}
+namespace cub
+{
+}
 CUB_NS_POSTFIX
 
 // Older versions of CUB do not define this. Set it to a reasonable default if
 // not provided.
-#ifndef CUB_NS_QUALIFIER
-#define CUB_NS_QUALIFIER ::cub
-#endif
+#  ifndef CUB_NS_QUALIFIER
+#    define CUB_NS_QUALIFIER ::cub
+#  endif
 
 #endif // THRUST_IGNORE_CUB_VERSION_CHECK
 
